# -*- coding: utf-8 -*-

"""
conftest
----------------------------------

Test fixtures `geosample` module.
"""

import pytest

import shapely.geometry as sg


@pytest.fixture
def shape():
    s = {
        "type": "Polygon",
        "coordinates": [
            [
                [
                    -124.45312499999999,
                    54.57206165565852
                ],
                [
                    -124.45312499999999,
                    49.61070993807422
                ],
                [
                    -119.17968749999999,
                    40.44694705960048
                ],
                [
                    -117.0703125,
                    52.05249047600099
                ],
                [
                    -124.45312499999999,
                    54.57206165565852
                ]
            ]
        ]
    }

    return sg.shape(s)


@pytest.fixture
def shapes():
    S = [
        {
            "type": "Polygon",
            "coordinates": [
                [
                    [
                        -124.45312499999999,
                        54.57206165565852
                    ],
                    [
                        -124.45312499999999,
                        49.61070993807422
                    ],
                    [
                        -119.17968749999999,
                        40.44694705960048
                    ],
                    [
                        -117.0703125,
                        52.05249047600099
                    ],
                    [
                        -124.45312499999999,
                        54.57206165565852
                    ]
                ]
            ]
        },
        {
            "type": "Polygon",
            "coordinates": [
                [
                    [
                        124.45312499999999,
                        -54.57206165565852
                    ],
                    [
                        124.45312499999999,
                        -49.61070993807422
                    ],
                    [
                        119.17968749999999,
                        -40.44694705960048
                    ],
                    [
                        117.0703125,
                        -52.05249047600099
                    ],
                    [
                        124.45312499999999,
                        -54.57206165565852
                    ]
                ]
            ]
        }
    ]

    return [sg.shape(s) for s in S]

@pytest.fixture
def geojson():
    return {
      "type": "FeatureCollection",
      "features": [
        {
          "type": "Feature",
          "properties": {
            "stroke": "#555555",
            "stroke-width": 2,
            "stroke-opacity": 1,
            "fill": "#555555",
            "fill-opacity": 0.5,
            "name": "na"
          },
          "geometry": {
            "type": "Polygon",
            "coordinates": [
              [
                [
                  -124.45312499999999,
                  54.57206165565852
                ],
                [
                  -124.45312499999999,
                  49.61070993807422
                ],
                [
                  -119.17968749999999,
                  40.44694705960048
                ],
                [
                  -117.0703125,
                  52.05249047600099
                ],
                [
                  -124.45312499999999,
                  54.57206165565852
                ]
              ]
            ]
          }
        },
        {
          "type": "Feature",
          "properties": {
            "stroke": "#555555",
            "stroke-width": 2,
            "stroke-opacity": 1,
            "fill": "#555555",
            "fill-opacity": 0.5,
            "name": "eu"
          },
          "geometry": {
            "type": "Polygon",
            "coordinates": [
              [
                [
                  3.1640625,
                  44.84029065139799
                ],
                [
                  8.7890625,
                  45.82879925192134
                ],
                [
                  24.609375,
                  46.07323062540835
                ],
                [
                  27.0703125,
                  43.58039085560784
                ],
                [
                  28.828124999999996,
                  50.28933925329178
                ],
                [
                  20.390625,
                  50.064191736659104
                ],
                [
                  12.65625,
                  50.064191736659104
                ],
                [
                  11.6015625,
                  47.517200697839414
                ],
                [
                  5.2734375,
                  47.040182144806664
                ],
                [
                  3.1640625,
                  44.84029065139799
                ]
              ]
            ]
          }
        },
        {
          "type": "Feature",
          "properties": {
            "stroke": "#555555",
            "stroke-width": 2,
            "stroke-opacity": 1,
            "fill": "#555555",
            "fill-opacity": 0.5,
            "name": "ru"
          },
          "geometry": {
            "type": "Polygon",
            "coordinates": [
              [
                [
                  101.953125,
                  66.37275500247455
                ],
                [
                  85.078125,
                  58.26328705248601
                ],
                [
                  86.1328125,
                  46.31658418182218
                ],
                [
                  102.65625,
                  51.83577752045248
                ],
                [
                  102.65625,
                  39.095962936305476
                ],
                [
                  110.74218749999999,
                  50.736455137010665
                ],
                [
                  101.953125,
                  58.44773280389084
                ],
                [
                  94.921875,
                  54.16243396806779
                ],
                [
                  97.03125,
                  59.712097173322924
                ],
                [
                  118.125,
                  61.938950426660604
                ],
                [
                  117.7734375,
                  65.36683689226321
                ],
                [
                  101.953125,
                  66.37275500247455
                ]
              ]
            ]
          }
        }
      ]
    }
